# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import CandidateHit, Component, LibraryCompoundInfo
from .FD import Feature, IFeatureSet, IScanSpace, ScanAxis
from .FeatureDataAccess import TofFeatureDataAccess

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration

class BestFitCriterionType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    BIC: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.BestFitCriterionType
    ) = ...  # static # readonly
    MinRmsResidual: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.BestFitCriterionType
    ) = ...  # static # readonly

class CalRefCompoundSet(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Alkanes: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefCompoundSet
    ) = ...  # static # readonly
    All: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefCompoundSet = (
        ...
    )  # static # readonly
    CycloSiloxanes: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefCompoundSet
    ) = ...  # static # readonly
    FAMEs: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefCompoundSet
    ) = ...  # static # readonly
    LinearSiloxanes: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefCompoundSet
    ) = ...  # static # readonly
    Matrix: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefCompoundSet
    ) = ...  # static # readonly

class CalRefDataSet(
    System.IDisposable,
    System.ComponentModel.ISupportInitializeNotification,
    System.IServiceProvider,
    System.Data.DataSet,
    System.Xml.Serialization.IXmlSerializable,
    System.Runtime.Serialization.ISerializable,
    System.ComponentModel.IListSource,
    System.ComponentModel.ISupportInitialize,
    System.ComponentModel.IComponent,
):  # Class
    def __init__(self) -> None: ...

    CalibrationCompound: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundDataTable
    )  # readonly
    CompoundReferenceIon: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonDataTable
    )  # readonly
    ReferenceIon: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonDataTable
    )  # readonly
    Relations: System.Data.DataRelationCollection  # readonly
    SchemaSerializationMode: System.Data.SchemaSerializationMode
    Tables: System.Data.DataTableCollection  # readonly

    @staticmethod
    def GetTypedDataSetSchema(
        xs: System.Xml.Schema.XmlSchemaSet,
    ) -> System.Xml.Schema.XmlSchemaComplexType: ...
    def Clone(self) -> System.Data.DataSet: ...

    # Nested Types

    class CalibrationCompoundDataTable(
        System.ComponentModel.ISupportInitialize,
        Iterable[Any],
        System.ComponentModel.ISupportInitializeNotification,
        System.Xml.Serialization.IXmlSerializable,
        System.ComponentModel.IComponent,
        System.Runtime.Serialization.ISerializable,
        System.Data.TypedTableBase[
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRow
        ],
        Iterable[
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRow
        ],
        System.ComponentModel.IListSource,
        System.IDisposable,
        System.IServiceProvider,
    ):  # Class
        def __init__(self) -> None: ...

        CASNumberColumn: System.Data.DataColumn  # readonly
        CompoundIDColumn: System.Data.DataColumn  # readonly
        Count: int  # readonly
        FormulaColumn: System.Data.DataColumn  # readonly
        def __getitem__(
            self, index: int
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRow
        ): ...
        LadderColumn: System.Data.DataColumn  # readonly
        LadderStepColumn: System.Data.DataColumn  # readonly
        NameColumn: System.Data.DataColumn  # readonly
        RetentionIndexColumn: System.Data.DataColumn  # readonly

        @staticmethod
        def GetTypedTableSchema(
            xs: System.Xml.Schema.XmlSchemaSet,
        ) -> System.Xml.Schema.XmlSchemaComplexType: ...
        @overload
        def AddCalibrationCompoundRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRow,
        ) -> None: ...
        @overload
        def AddCalibrationCompoundRow(
            self,
            CompoundID: int,
            CASNumber: str,
            Formula: str,
            Ladder: str,
            LadderStep: str,
            Name: str,
            RetentionIndex: float,
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRow
        ): ...
        def Clone(self) -> System.Data.DataTable: ...
        def RemoveCalibrationCompoundRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRow,
        ) -> None: ...
        def NewCalibrationCompoundRow(
            self,
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRow
        ): ...
        def FindByCompoundID(
            self, CompoundID: int
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRow
        ): ...

        CalibrationCompoundRowChanged: (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRowChangeEventHandler
        )  # Event
        CalibrationCompoundRowChanging: (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRowChangeEventHandler
        )  # Event
        CalibrationCompoundRowDeleted: (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRowChangeEventHandler
        )  # Event
        CalibrationCompoundRowDeleting: (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRowChangeEventHandler
        )  # Event

    class CalibrationCompoundRow(System.Data.DataRow):  # Class
        CASNumber: str
        CompoundID: int
        Formula: str
        Ladder: str
        LadderStep: str
        Name: str
        RetentionIndex: float

        def SetLadderNull(self) -> None: ...
        def IsCASNumberNull(self) -> bool: ...
        def IsNameNull(self) -> bool: ...
        def IsLadderNull(self) -> bool: ...
        def SetLadderStepNull(self) -> None: ...
        def IsFormulaNull(self) -> bool: ...
        def GetCompoundReferenceIonRows(
            self,
        ) -> List[
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonRow
        ]: ...
        def IsLadderStepNull(self) -> bool: ...
        def SetNameNull(self) -> None: ...
        def SetFormulaNull(self) -> None: ...
        def SetRetentionIndexNull(self) -> None: ...
        def SetCASNumberNull(self) -> None: ...
        def IsRetentionIndexNull(self) -> bool: ...

    class CalibrationCompoundRowChangeEvent(System.EventArgs):  # Class
        def __init__(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRow,
            action: System.Data.DataRowAction,
        ) -> None: ...

        Action: System.Data.DataRowAction  # readonly
        Row: (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRow
        )  # readonly

    class CalibrationCompoundRowChangeEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRowChangeEvent,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRowChangeEvent,
        ) -> None: ...

    class CompoundReferenceIonDataTable(
        System.IServiceProvider,
        System.ComponentModel.ISupportInitialize,
        Iterable[Any],
        System.ComponentModel.ISupportInitializeNotification,
        System.Xml.Serialization.IXmlSerializable,
        System.ComponentModel.IComponent,
        System.Runtime.Serialization.ISerializable,
        Iterable[
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonRow
        ],
        System.ComponentModel.IListSource,
        System.IDisposable,
        System.Data.TypedTableBase[
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonRow
        ],
    ):  # Class
        def __init__(self) -> None: ...

        CompoundIDColumn: System.Data.DataColumn  # readonly
        Count: int  # readonly
        def __getitem__(
            self, index: int
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonRow
        ): ...
        ReferenceIonIDColumn: System.Data.DataColumn  # readonly
        RelativeAbundanceColumn: System.Data.DataColumn  # readonly

        @overload
        def AddCompoundReferenceIonRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonRow,
        ) -> None: ...
        @overload
        def AddCompoundReferenceIonRow(
            self,
            parentCalibrationCompoundRowByFK_CalibrationCompound_CompoundReferenceIon: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRow,
            parentReferenceIonRowByFK_ReferenceIon_CompoundReferenceIon: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRow,
            RelativeAbundance: float,
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonRow
        ): ...
        @staticmethod
        def GetTypedTableSchema(
            xs: System.Xml.Schema.XmlSchemaSet,
        ) -> System.Xml.Schema.XmlSchemaComplexType: ...
        def NewCompoundReferenceIonRow(
            self,
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonRow
        ): ...
        def RemoveCompoundReferenceIonRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonRow,
        ) -> None: ...
        def Clone(self) -> System.Data.DataTable: ...
        def FindByCompoundIDReferenceIonID(
            self, CompoundID: int, ReferenceIonID: int
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonRow
        ): ...

        CompoundReferenceIonRowChanged: (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonRowChangeEventHandler
        )  # Event
        CompoundReferenceIonRowChanging: (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonRowChangeEventHandler
        )  # Event
        CompoundReferenceIonRowDeleted: (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonRowChangeEventHandler
        )  # Event
        CompoundReferenceIonRowDeleting: (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonRowChangeEventHandler
        )  # Event

    class CompoundReferenceIonRow(System.Data.DataRow):  # Class
        CalibrationCompoundRow: (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRow
        )
        CompoundID: int
        ReferenceIonID: int
        ReferenceIonRow: (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRow
        )
        RelativeAbundance: float

        def IsRelativeAbundanceNull(self) -> bool: ...
        def SetRelativeAbundanceNull(self) -> None: ...

    class CompoundReferenceIonRowChangeEvent(System.EventArgs):  # Class
        def __init__(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonRow,
            action: System.Data.DataRowAction,
        ) -> None: ...

        Action: System.Data.DataRowAction  # readonly
        Row: (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonRow
        )  # readonly

    class CompoundReferenceIonRowChangeEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonRowChangeEvent,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonRowChangeEvent,
        ) -> None: ...

    class ReferenceIonDataTable(
        System.IServiceProvider,
        System.ComponentModel.ISupportInitialize,
        Iterable[Any],
        System.ComponentModel.ISupportInitializeNotification,
        System.Xml.Serialization.IXmlSerializable,
        Iterable[
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRow
        ],
        System.ComponentModel.IComponent,
        System.Runtime.Serialization.ISerializable,
        System.ComponentModel.IListSource,
        System.IDisposable,
        System.Data.TypedTableBase[
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRow
        ],
    ):  # Class
        def __init__(self) -> None: ...

        Count: int  # readonly
        ExactMassEIColumn: System.Data.DataColumn  # readonly
        FormulaColumn: System.Data.DataColumn  # readonly
        def __getitem__(
            self, index: int
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRow
        ): ...
        ReferenceIonIDColumn: System.Data.DataColumn  # readonly

        @overload
        def AddReferenceIonRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRow,
        ) -> None: ...
        @overload
        def AddReferenceIonRow(
            self, ReferenceIonID: int, ExactMassEI: float, Formula: str
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRow
        ): ...
        @staticmethod
        def GetTypedTableSchema(
            xs: System.Xml.Schema.XmlSchemaSet,
        ) -> System.Xml.Schema.XmlSchemaComplexType: ...
        def NewReferenceIonRow(
            self,
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRow
        ): ...
        def FindByReferenceIonID(
            self, ReferenceIonID: int
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRow
        ): ...
        def Clone(self) -> System.Data.DataTable: ...
        def RemoveReferenceIonRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRow,
        ) -> None: ...

        ReferenceIonRowChanged: (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRowChangeEventHandler
        )  # Event
        ReferenceIonRowChanging: (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRowChangeEventHandler
        )  # Event
        ReferenceIonRowDeleted: (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRowChangeEventHandler
        )  # Event
        ReferenceIonRowDeleting: (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRowChangeEventHandler
        )  # Event

    class ReferenceIonRow(System.Data.DataRow):  # Class
        ExactMassEI: float
        Formula: str
        ReferenceIonID: int

        def IsExactMassEINull(self) -> bool: ...
        def IsFormulaNull(self) -> bool: ...
        def GetCompoundReferenceIonRows(
            self,
        ) -> List[
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CompoundReferenceIonRow
        ]: ...
        def SetFormulaNull(self) -> None: ...
        def SetExactMassEINull(self) -> None: ...

    class ReferenceIonRowChangeEvent(System.EventArgs):  # Class
        def __init__(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRow,
            action: System.Data.DataRowAction,
        ) -> None: ...

        Action: System.Data.DataRowAction  # readonly
        Row: (
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRow
        )  # readonly

    class ReferenceIonRowChangeEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRowChangeEvent,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRowChangeEvent,
        ) -> None: ...

class CalibrationReferenceDB:  # Class
    def __init__(self) -> None: ...
    def GetCompoundByCASNumber(
        self, casNumber: str
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRow
    ): ...
    @overload
    def Open(self, dataSourcePath: str) -> None: ...
    @overload
    def Open(
        self,
        calRefCompoundSet: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefCompoundSet,
    ) -> None: ...
    @overload
    def Open(self, dataSourcePaths: List[str]) -> None: ...

class DynamicCalibrationParams:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, xmlFilePath: str) -> None: ...
    @overload
    def __init__(
        self,
        other: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.DynamicCalibrationParams,
    ) -> None: ...

    PARAMETER_FILE: str = ...  # static # readonly

    ApplyMassCalToFeatures: bool
    BestFitCriterion: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.BestFitCriterionType
    )
    CalRefCompoundSet: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefCompoundSet
    )
    MassCalRTInterpolationType: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.MassCalRTInterpolationType
    )
    MaxInversePower: int
    MaxPolynomialOrder: int
    MaxResolvingPower: float
    MinComponentQuality: float
    MinIonMatchCount: int
    MinMatchScore: float
    MinPolynomialOrder: int
    MzTolerancePpm: float
    RModelRolloverMzScale: float
    RefLibraryPath: str
    WindowSizeFactorsForDeconvolution: List[float]

    def Equals(
        self,
        other: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.DynamicCalibrationParams,
    ) -> bool: ...
    def Clone(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.DynamicCalibrationParams
    ): ...

class FeatureCalibrator:  # Class
    def __init__(
        self, dataAccess: TofFeatureDataAccess, featureSet: IFeatureSet
    ) -> None: ...
    def Run(self) -> None: ...

class FeatureMassCalibrationRecord:  # Class
    def __init__(
        self,
        refCompoundMatch: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.ReferenceCompoundMatch,
        refIonMatches: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.ReferenceIonMatch
        ],
        dcParams: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.DynamicCalibrationParams,
    ) -> None: ...

    CalibrationCompound: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRow
    )  # readonly
    IdentifiedComponent: Component  # readonly
    IonMatchList: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.ReferenceIonMatch
    ]  # readonly
    MassCalFit: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.MassCalibrationFit
    )  # readonly
    NIons: int  # readonly
    ReferenceCompoundMatch: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.ReferenceCompoundMatch
    )  # readonly
    RetentionTime: float  # readonly

    def FindOptimalFit(
        self,
        ftAxis: ScanAxis,
        rModel: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.ResolvingPowerModel,
    ) -> None: ...

class FeatureMassTimeCalibration:  # Class
    def __init__(
        self,
        scanSpace: IScanSpace,
        dcParams: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.DynamicCalibrationParams,
    ) -> None: ...

    NRecords: int  # readonly

    def AddMassTimeCalRecord(
        self,
        massCalRecord: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.FeatureMassCalibrationRecord,
    ) -> None: ...
    def CompleteCalibration(self, featureSet: IFeatureSet) -> None: ...
    def GetMassForFeature(self, f: Feature) -> float: ...

class GlobalAverageMassCal:  # Class
    def __init__(
        self,
        parent: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.FeatureMassTimeCalibration,
        ftAxis: ScanAxis,
        rModel: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.ResolvingPowerModel,
    ) -> None: ...
    def GetMassCorrection(self, mz: float) -> float: ...
    def Run(
        self,
        calRecords: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.FeatureMassCalibrationRecord
        ],
        polynomialOrder: int,
        maxInversePower: int,
    ) -> None: ...

class MassCalRTInterpolationType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    GlobalAverage: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.MassCalRTInterpolationType
    ) = ...  # static # readonly
    Linear: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.MassCalRTInterpolationType
    ) = ...  # static # readonly
    NearestPoint: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.MassCalRTInterpolationType
    ) = ...  # static # readonly
    Quadratic: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.MassCalRTInterpolationType
    ) = ...  # static # readonly

class MassCalibrationFit:  # Class
    def __init__(
        self,
        mzRef: List[float],
        flightTimes: List[float],
        flightTimeAxis: ScanAxis,
        rModel: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.ResolvingPowerModel,
    ) -> None: ...

    BestResidualFit: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.MassCalibrationFitStep
    )  # readonly
    MaxInversePower: int  # readonly
    NIons: int  # readonly
    ParabolicFit: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.MassCalibrationFitStep
    )  # readonly
    PolynomialOrder: int  # readonly
    RmsTotalResidualPpm: float  # readonly
    TotalResiduals: List[float]  # readonly
    TotalResidualsPpm: List[float]  # readonly

    def IsFlightTimeInRange(self, flightTime: float) -> bool: ...
    def ConvertTimeToMass(self, flightTime: float) -> float: ...
    def FindBestFit(
        self,
        bestFitCriterion: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.BestFitCriterionType,
        minPolynomialOrder: int,
        maxPolynomialOrder: int,
        maxInversePower: int,
    ) -> None: ...

class MassCalibrationFitStep:  # Class
    def __init__(
        self,
        mz: List[float],
        mzRef: List[float],
        flightTimes: List[float],
        flightTimeAxis: ScanAxis,
        polynomialOrder: int,
        nInversePowers: int,
        rModel: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.ResolvingPowerModel,
    ) -> None: ...

    BayesianInformationCriterion: float  # readonly
    ChiSquare: float  # readonly
    Coefficients: List[float]  # readonly
    MaxInversePower: int  # readonly
    PolynomialOrder: int  # readonly
    Residuals: List[float]  # readonly
    ResidualsPpm: List[float]  # readonly
    RmsResidualPpm: float  # readonly

    def ConvertTimeToMass(self, flightTime: float) -> float: ...
    def DoFit(self) -> None: ...

class MassResidualFit:  # Class
    def __init__(
        self,
        mzMeasured: List[float],
        mzRef: List[float],
        polynomialOrder: int,
        nInversePowers: int,
        rModel: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.ResolvingPowerModel,
    ) -> None: ...

    BayesianInformationCriterion: float  # readonly
    ChiSquare: float  # readonly
    Coefficients: List[float]  # readonly
    MaxInversePower: int  # readonly
    MzDelta: List[float]  # readonly
    MzDeltaFit: List[float]  # readonly
    MzDeltaFitPpm: List[float]  # readonly
    MzDeltaPpm: List[float]  # readonly
    PolynomialOrder: int  # readonly
    Residuals: List[float]  # readonly
    ResidualsPpm: List[float]  # readonly
    RmsResidualPpm: float  # readonly

    def GetMassCorrection(self, mz: float) -> float: ...
    def DoFit(self) -> None: ...

class RTCal:  # Class
    def __init__(
        self,
        _calRecords: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.FeatureMassCalibrationRecord
        ],
    ) -> None: ...

class ReferenceCompoundMatch:  # Class
    def __init__(
        self,
        refCompound: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRow,
        component: Component,
        hit: CandidateHit,
        compoundInfo: LibraryCompoundInfo,
        ladderType: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefCompoundSet,
    ) -> None: ...

    CalibrationCompound: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.CalibrationCompoundRow
    )  # readonly
    IdentifiedComponent: Component  # readonly
    LadderType: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefCompoundSet
    )  # readonly
    LibraryHit: CandidateHit  # readonly

    def GetReferenceIonMatches(
        self, featureSet: IFeatureSet, mzTolerancePpm: float
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.ReferenceIonMatch
    ]: ...

    # Nested Types

    class RTComparer(
        System.Collections.Generic.IComparer[
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.ReferenceCompoundMatch
        ]
    ):  # Class
        def __init__(self) -> None: ...
        def Compare(
            self,
            a: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.ReferenceCompoundMatch,
            b: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.ReferenceCompoundMatch,
        ) -> int: ...

class ReferenceIonMatch:  # Class
    def __init__(
        self,
        refIon: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.CalRefDataSet.ReferenceIonRow,
        feature: Feature,
    ) -> None: ...

    Abundance: float  # readonly
    ExactMassEI: float  # readonly
    MeasuredFlightTime: float  # readonly
    MeasuredMz: float  # readonly

    # Nested Types

    class MzComparer(
        System.Collections.Generic.IComparer[
            Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.ReferenceIonMatch
        ]
    ):  # Class
        def __init__(self) -> None: ...
        def Compare(
            self,
            a: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.ReferenceIonMatch,
            b: Agilent.MassSpectrometry.DataAnalysis.FeatureCalibration.ReferenceIonMatch,
        ) -> int: ...

class ResolvingPowerModel:  # Class
    def __init__(self, r0: float, mz0: float) -> None: ...

    Mz0: float  # readonly
    R0: float  # readonly

    def GetMassResolutionSquared(self, mz: float) -> float: ...
    def GetResolvingPowerSquared(self, mz: float) -> float: ...
    def GetResolvingPower(self, mz: float) -> float: ...
    def GetMassResolution(self, mz: float) -> float: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Utils import (
    CompoundGraphicsKey,
    CompoundGraphicsRangeColumnValueParameter,
    FormattingColumnValueParameter,
    FormattingKey,
    KeyValue,
    PrePostProcessColumnValueParameter,
    PrePostProcessKey,
    ReportColumnValueParameter,
)

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand

class AppCommandBase(
    Agilent.MassSpectrometry.CommandModel.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    ActionString: str  # readonly
    Name: str  # readonly

    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...

class ApplicationType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    QuantAnalysis: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.ApplicationType
    ) = ...  # static # readonly
    UnknownsAnalysis: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.ApplicationType
    ) = ...  # static # readonly
    Unspecified: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.ApplicationType
    ) = ...  # static # readonly

class Context(
    Agilent.MassSpectrometry.CommandModel.Model.ICommandHistory,
    Agilent.MassSpectrometry.CommandModel.CommandHistory,
    System.IDisposable,
):  # Class
    def __init__(self) -> None: ...

    AuditTrail: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IAuditTrail
    )  # readonly
    Compliance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance
    )  # readonly
    CurrentReportID: int  # readonly
    IsDirty: bool  # readonly
    PathName: str  # readonly
    ReportMethodDataSet: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet
    )  # readonly

    def Invoke(
        self, cmd: Agilent.MassSpectrometry.CommandModel.Model.ICommand
    ) -> Any: ...
    def NewMethod(self) -> None: ...

    CalibrationGraphicsPropertiesChanged: System.EventHandler  # Event
    CompoundGraphicsRangeCountChanged: System.EventHandler  # Event
    CompoundGraphicsRangePropertiesChanged: System.EventHandler  # Event
    FormattingCountChanged: System.EventHandler  # Event
    FormattingPropertiesChanged: System.EventHandler  # Event
    GraphicsRangePropertiesChanged: System.EventHandler  # Event
    MethodClosed: System.EventHandler  # Event
    MethodClosing: System.EventHandler  # Event
    MethodOpened: System.EventHandler  # Event
    MethodOpening: System.EventHandler  # Event
    MethodSaved: System.EventHandler  # Event
    PeakChromatogramGraphicsPropertiesChanged: System.EventHandler  # Event
    PeakQualifiersGraphicsPropertiesChanged: System.EventHandler  # Event
    PeakSpectrumGraphicsPropertiesChanged: System.EventHandler  # Event
    PrePostProcessCountChanged: System.EventHandler  # Event
    PrePostProcessPropertiesChanged: System.EventHandler  # Event
    ReportPropertiesChanged: System.EventHandler  # Event
    SampleChromatogramGraphicsPropertiesChanged: System.EventHandler  # Event

class Delete(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        formattings: List[FormattingKey],
        formattingProperties: List[FormattingColumnValueParameter],
        prePostProcesses: List[PrePostProcessKey],
    ) -> None: ...

    ActionString: str  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def DeleteFormatting(self, reportID: int, formattingID: int) -> None: ...
    def DeleteFormattingProperty(
        self, reportID: int, formattingID: int, name: str
    ) -> None: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def DeletePrePostProcessProperty(
        self, reportID: int, prePostProcessID: int
    ) -> None: ...

class NewFormattings(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        parameters: List[FormattingColumnValueParameter],
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...

    ActionString: str  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def AddFormatting(
        self, reportId: int, formattingId: int, values: List[KeyValue]
    ) -> None: ...
    def Redo(self) -> Any: ...
    @staticmethod
    def FindNewID(
        ds: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
    ) -> int: ...
    def Undo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...

class NewMethod(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...

    ActionString: str  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class NewPrePostProcess(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        reportID: int,
        prePostProcessID: int,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        reportID: int,
        prePostProcessID: int,
        values: List[KeyValue],
    ) -> None: ...

    ActionString: str  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    @staticmethod
    def FindNewID(
        ds: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethod.ReportMethodDataSet,
        reportID: int,
    ) -> int: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def SetProperty(self, name: str, value_: Any) -> None: ...

class Open(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        pathName: str,
        revisionNumber: str,
        readOnly: bool,
    ) -> None: ...

    ActionString: str  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class RedoCommand(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...

    ActionString: str  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class Save(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...

    ActionString: str  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class SaveAs(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        pathName: str,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        pathName: str,
        ok: bool,
    ) -> None: ...

    ActionString: str  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class SetCalibrationGraphicsProperties(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.SetGraphicsPropertiesBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        parameters: List[ReportColumnValueParameter],
    ) -> None: ...

    ActionString: str  # readonly
    PropertyCount: int  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def SetProperty(self, reportID: int, name: str, value_: Any) -> None: ...

class SetFormattingProperties(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        parameters: List[FormattingColumnValueParameter],
    ) -> None: ...

    ActionString: str  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def SetProperty(
        self, reportID: int, formattingID: int, name: str, value_: Any
    ) -> None: ...

class SetGraphicsPropertiesBase(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...
    def SetProperty(self, reportID: int, name: str, value_: Any) -> None: ...

class SetGraphicsRanges(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        graphicsRangeProperties: List[ReportColumnValueParameter],
        deleteCompoundGraphicsKeys: List[CompoundGraphicsKey],
        newCompoundGraphicsKeys: List[CompoundGraphicsKey],
        compoundGraphicsProperties: List[CompoundGraphicsRangeColumnValueParameter],
    ) -> None: ...

    ActionString: str  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def SetCompoundGraphicsProperty(
        self, reportID: int, compoundGraphicsID: int, name: str, value_: Any
    ) -> None: ...
    def AddCompoundGraphicsRange(
        self, reportID: int, compoundGraphicsID: int
    ) -> None: ...
    def DeleteCompoundGraphicsRange(
        self, reportID: int, compoundGraphicsID: int
    ) -> None: ...
    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def SetGraphicsRange(self, reportID: int, name: str, value_: Any) -> None: ...

class SetPeakChromatogramGraphicsProperties(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.SetGraphicsPropertiesBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        parameters: List[ReportColumnValueParameter],
    ) -> None: ...

    ActionString: str  # readonly
    PropertyCount: int  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def SetProperty(self, reportID: int, name: str, value_: Any) -> None: ...

class SetPeakQualifiersGraphicsProperties(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.SetGraphicsPropertiesBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        parameters: List[ReportColumnValueParameter],
    ) -> None: ...

    ActionString: str  # readonly
    PropertyCount: int  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def SetProperty(self, reportID: int, name: str, value_: Any) -> None: ...

class SetPeakSpectrumGraphicsProperties(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.SetGraphicsPropertiesBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        parameters: List[ReportColumnValueParameter],
    ) -> None: ...

    ActionString: str  # readonly
    PropertyCount: int  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def SetProperty(self, reportID: int, name: str, value_: Any) -> None: ...

class SetPrePostProcessProperties(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        parameters: List[PrePostProcessColumnValueParameter],
    ) -> None: ...

    ActionString: str  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def SetProperty(
        self, reportID: int, prePostProcessID: int, name: str, value_: Any
    ) -> None: ...

class SetReportProperties(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        parameters: List[ReportColumnValueParameter],
    ) -> None: ...

    ActionString: str  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def SetProperty(self, reportID: int, name: str, value_: Any) -> None: ...

class SetSampleChromatogramGraphicsProperties(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.SetGraphicsPropertiesBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        parameters: List[ReportColumnValueParameter],
    ) -> None: ...

    ActionString: str  # readonly
    PropertyCount: int  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def SetProperty(self, reportID: int, name: str, value_: Any) -> None: ...

class SetUnknownsIonPeakGraphicsProperties(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.SetGraphicsPropertiesBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        parameters: List[ReportColumnValueParameter],
    ) -> None: ...

    ActionString: str  # readonly
    PropertyCount: int  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def SetProperty(self, reportID: int, name: str, value_: Any) -> None: ...

class SetUnknownsSampleChromatogramGraphicsProperties(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.SetGraphicsPropertiesBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        parameters: List[ReportColumnValueParameter],
    ) -> None: ...

    ActionString: str  # readonly
    PropertyCount: int  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def SetProperty(self, reportID: int, name: str, value_: Any) -> None: ...

class SetUnknownsSpectrumGraphicsProperties(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.SetGraphicsPropertiesBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
        parameters: List[ReportColumnValueParameter],
    ) -> None: ...

    ActionString: str  # readonly
    PropertyCount: int  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def SetProperty(self, reportID: int, name: str, value_: Any) -> None: ...

class UndoCommand(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IComplianceCommand,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.AppCommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.AppCommand.Context,
    ) -> None: ...

    ActionString: str  # readonly
    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .PlotControl import IPeaks, IPlotBar, IPlotSeries, PlotAxesControl, PlotPeakSeries
from .UIModel import IDataNavigator

# Stubs for namespace: Agilent.MassHunter.Quantitative.Screening

class ItemStatus(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Error: Agilent.MassHunter.Quantitative.Screening.ItemStatus = (
        ...
    )  # static # readonly
    Good: Agilent.MassHunter.Quantitative.Screening.ItemStatus = (
        ...
    )  # static # readonly
    Warning: Agilent.MassHunter.Quantitative.Screening.ItemStatus = (
        ...
    )  # static # readonly

class SampleItem:  # Class
    def __init__(self, sampleID: int, name: str) -> None: ...

    Name: str  # readonly
    SampleID: int  # readonly

    def ToString(self) -> str: ...

class ScreeningControl(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class ScreeningTable(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Controls.DataGrid,
    System.Windows.Media.Animation.IAnimatable,
    MS.Internal.Controls.IGeneratorHost,
    System.ComponentModel.ISupportInitialize,
    System.Windows.IInputElement,
    System.Windows.Markup.IAddChild,
    System.Windows.IFrameworkInputElement,
    System.Windows.Controls.Primitives.IContainItemStorage,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class ScreeningTableItem:  # Class
    def __init__(self) -> None: ...

    BatchID: int  # readonly
    CASNumber: str  # readonly
    CompoundID: int  # readonly
    CompoundName: str  # readonly
    ExpectedRetentionTime: float  # readonly
    FinalConcentration: Optional[float]  # readonly
    MZ: float  # readonly
    MassAccuracy: Optional[float]  # readonly
    MassMatchScore: Optional[float]  # readonly
    MolecularFormula: str  # readonly
    NumberOfQualifiedIons: int  # readonly
    OutlierCount: int  # readonly
    OutlierMassAccuracy: bool  # readonly
    OutlierMassMatchScore: bool  # readonly
    OutlierNumberOfQualifiedIons: bool  # readonly
    OutlierReferenceLibraryMatchScore: bool  # readonly
    OutlierRetentionTimeDifference: bool  # readonly
    PeakRetentionTime: Optional[float]  # readonly
    ReferenceLibraryMatchScore: Optional[float]  # readonly
    RetentionTimeDifference: Optional[float]  # readonly
    SampleID: int  # readonly
    Status: Agilent.MassHunter.Quantitative.Screening.ItemStatus  # readonly

    def Initialize(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow,
        peak: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.PeakRow,
        useReferenceLibraryMatchScore: bool,
        useMassMatchScore: bool,
        useQualifierRatio: bool,
    ) -> None: ...

class ScreeningTableModel(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.NotifyPropertyBase,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(
        self,
        table: Agilent.MassHunter.Quantitative.Screening.ScreeningTable,
        navigator: IDataNavigator,
    ) -> None: ...

    CompoundCountCheck: int  # readonly
    CompoundCountError: int  # readonly
    CompoundCountTotal: int  # readonly
    CompoundCountWarning: int  # readonly
    Items: List[
        Agilent.MassHunter.Quantitative.Screening.ScreeningTableItem
    ]  # readonly
    ShowGreenItems: bool
    ShowMassMatchScore: bool
    ShowOrangeItems: bool
    ShowRedItems: bool
    ShowReferenceLibraryMatchScore: bool
    UseQualifierRatio: bool
    View: System.ComponentModel.ICollectionView  # readonly

    def UpdateSample(self, sampleID: int) -> None: ...
    def Disconnect(self) -> None: ...
    def UpdateData(self) -> None: ...

class ScreeningWindow(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.IWindowService,
    Infragistics.Windows.Ribbon.IRibbonWindow,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Animation.IAnimatable,
    System.ComponentModel.ISupportInitialize,
    Infragistics.Windows.Ribbon.XamRibbonWindow,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.Windows.Markup.IAddChild,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IHaveResources,
):  # Class
    IstotopeSpectrumVisible: bool

    def InitGC(self) -> None: ...
    def InitLC(self) -> None: ...
    def InitializeComponent(self) -> None: ...
    def ShowAndActivate(self) -> None: ...
    @staticmethod
    def GetInstance(
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
    ) -> Agilent.MassHunter.Quantitative.Screening.ScreeningWindow: ...

class SpectrumAverageHandler(
    Agilent.MassHunter.Quantitative.Screening.SpectrumHandlerBase
):  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Screening.SpectrumHandler,
        plot: PlotAxesControl,
    ) -> None: ...
    def _UpdateData(self) -> None: ...
    @staticmethod
    def GetXRange(
        serieses: Iterable[IPlotSeries], minx: float, maxx: float
    ) -> None: ...

class SpectrumHandler:  # Class
    def __init__(
        self,
        plot: PlotAxesControl,
        simplifiedPlot: PlotAxesControl,
        isotopePlot: PlotAxesControl,
        dataNavigator: IDataNavigator,
    ) -> None: ...

    DataNavigator: IDataNavigator  # readonly
    SpectrumAverageHandler: (
        Agilent.MassHunter.Quantitative.Screening.SpectrumAverageHandler
    )  # readonly
    SpectrumError: str  # readonly
    SpectrumIsotopeHandler: (
        Agilent.MassHunter.Quantitative.Screening.SpectrumIsotopeHandler
    )  # readonly
    SpectrumSimplifiedHandler: (
        Agilent.MassHunter.Quantitative.Screening.SpectrumSimplifiedHandler
    )  # readonly

    def GetSpectrum(self) -> Agilent.MassSpectrometry.DataAnalysis.ISpectrum: ...
    @staticmethod
    def SetPlotTitle(plot: PlotAxesControl, title: str) -> None: ...
    def Disconnect(self) -> None: ...
    @staticmethod
    def ClearPlot(plot: PlotAxesControl) -> None: ...
    def GetReferenceLibrarySpectrum(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.ISpectrum: ...

class SpectrumHandlerBase:  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Screening.SpectrumHandler,
        plot: PlotAxesControl,
    ) -> None: ...

    PlotAxesControl: PlotAxesControl  # readonly

    def Disconnect(self) -> None: ...

class SpectrumIsotopeHandler(
    Agilent.MassHunter.Quantitative.Screening.SpectrumHandlerBase
):  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Screening.SpectrumHandler,
        plot: PlotAxesControl,
    ) -> None: ...
    def _UpdateData(self) -> None: ...

    # Nested Types

    class BarSeries(PlotPeakSeries, IPlotSeries, IPlotBar, IPeaks):  # Class
        def __init__(self) -> None: ...
        def SetIonsMatch(
            self, ionsMatch: Iterable[Agilent.MassSpectrometry.IIonMatch]
        ) -> None: ...
        def GetBarRange(self, index: int, start: float, end: float) -> None: ...
        def GetPeakLabelBrush(self, index: int) -> System.Windows.Media.Brush: ...
        def GetLinePen(self, index: int) -> System.Windows.Media.Pen: ...
        def GetFillBrush(self, index: int) -> System.Windows.Media.Brush: ...

class SpectrumSimplifiedHandler(
    Agilent.MassHunter.Quantitative.Screening.SpectrumHandlerBase
):  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Screening.SpectrumHandler,
        plot: PlotAxesControl,
    ) -> None: ...
    def _UpdateData(self) -> None: ...

class ToolbarHandler(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.NotifyPropertyBase,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(
        self,
        toolbar: System.Windows.Controls.ToolBar,
        tableModel: Agilent.MassHunter.Quantitative.Screening.ScreeningTableModel,
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
    ) -> None: ...

    Command_NextSample: System.Windows.Input.ICommand  # readonly
    Command_PrevSample: System.Windows.Input.ICommand  # readonly
    TableModel: (
        Agilent.MassHunter.Quantitative.Screening.ScreeningTableModel
    )  # readonly

    def NextSample(self, p: Any) -> None: ...
    def CanPrevSample(self, p: Any) -> bool: ...
    def PrevSample(self, p: Any) -> None: ...
    def CanNextSample(self, p: Any) -> bool: ...
    def Disconnect(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.MSDChem.QDB

class QDB:  # Class
    def __init__(self) -> None: ...

class QUANT_AUX_REPORTING_INFO:  # Class
    cpndType: str

class QUANT_CALIB_LEVEL_INFO:  # Class
    def __init__(self, dConcentration: float, dResponse: float) -> None: ...

    AverageCounter: int
    Concentration: float
    HasNullConcentration: bool  # readonly
    HasNullResponse: bool  # readonly
    IsValid: bool  # readonly
    Response: float

    @staticmethod
    def IsNullConcentration(dConcentration: float) -> bool: ...
    @staticmethod
    def IsNullResponse(dResponse: float) -> bool: ...

class QUANT_CPNDENTRY:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self, other: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_CPNDENTRY
    ) -> None: ...

    MATRIX_A: int = ...  # static # readonly
    MATRIX_B: int = ...  # static # readonly
    QUANT_ABSOLUTE: int = ...  # static # readonly
    QUANT_AVG_FIRST_LAST: int = ...  # static # readonly
    QUANT_AVG_RESPONSE_FACTOR_FIT: int = ...  # static # readonly
    QUANT_CLOSE_RT: int = ...  # static # readonly
    QUANT_CLOSE_RT_QUAL: int = ...  # static # readonly
    QUANT_DEFAULT_QHITS_MAX: int = ...  # static # readonly
    QUANT_EXTENDED_AREA: int = ...  # static # readonly
    QUANT_GREATEST_QVALUE: int = ...  # static # readonly
    QUANT_GREATEST_RESP: int = ...  # static # readonly
    QUANT_INV_SQ_WEIGHT: int = ...  # static # readonly
    QUANT_INV_WEIGHT: int = ...  # static # readonly
    QUANT_LINEAR_REGRESSION: int = ...  # static # readonly
    QUANT_LIN_REGR_ORIGIN: int = ...  # static # readonly
    QUANT_LOW_FIRST_LAST: int = ...  # static # readonly
    QUANT_MAX_AMU: float = ...  # static # readonly
    QUANT_MINUTES: int = ...  # static # readonly
    QUANT_NOT_AN_ISTD: int = ...  # static # readonly
    QUANT_NO_SUBTRACTION: int = ...  # static # readonly
    QUANT_NO_WEIGHT: int = ...  # static # readonly
    QUANT_NULL_CONC: float  # static
    QUANT_NULL_RESPONSE: float  # static
    QUANT_NUM_CALIB_LEVELS: int = ...  # static # readonly
    QUANT_NUM_QUALIFIER_IONS: int = ...  # static # readonly
    QUANT_PERCENT: int = ...  # static # readonly
    QUANT_QUADRATIC_REGRESSION: int = ...  # static # readonly
    QUANT_QUAD_REGR_ORIGIN: int = ...  # static # readonly
    QUANT_RELATIVE: int = ...  # static # readonly
    QUANT_REPORTALL: int = ...  # static # readonly
    aux: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_AUX_REPORTING_INFO
    calib_level_info: List[Agilent.MassSpectrometry.MSDChem.QDB.QUANT_CALIB_LEVEL_INFO]
    curvefit_type: int
    istd_peak_: int
    qual_addl_info: List[
        Agilent.MassSpectrometry.MSDChem.QDB.QUANT_QUALIFIER_ADDITIONAL_INFO
    ]
    qualifier_ion: List[Agilent.MassSpectrometry.MSDChem.QDB.QUANT_QUALIFIER_ION]
    rt_d_left: float
    rt_d_right: float
    sequentialRecordNumber: int
    target_signal: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_TARGET_SIGNAL
    tgt_addl_info: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_TARGET_ADDITIONAL_INFO

    AreaCorrectionFactor: float
    AreaCorrectionMz20ths: int
    CASid: str
    CompoundName: str
    CompoundType: str
    ConcentrationUnitsName: str
    CurveFitType: int
    CurveWeightType: int
    ExtractWindowType: int
    GCSignalNumber: int
    IsIstd: bool  # readonly
    IsQuantitatedWith: int  # readonly
    IsQuantitatedWithTIC: bool
    IsSemiQuantCompound: bool  # readonly
    IsTargetCompound: bool  # readonly
    IsTimeReference: bool
    MSDatabaseEntryNum: int
    MSDatabaseName: str
    MatrixSpikeAmount: float
    MaxHitsToReport: int
    MaxSignalLevel: float
    MinSignalLevel: float
    PeakSelectCriterion: int
    QualifierRatioMethod: int
    QualifierUncertaintyType: int
    QuantitatedByHeight: bool
    RTDeltaLeft: float
    RTDeltaRight: float
    ReferenceSpectrumName: str
    SampleIstdConc: float
    SequentialRecordNumber: int  # readonly
    SurrogateAmount: float
    TargetIntegPFName: str
    TargetMz20ths: int
    TargetRTMsec: int
    UsesAreaCorrection: bool  # readonly
    UsesLinearCurveFit: bool  # readonly

    @staticmethod
    def ClampToLegalRtRange(dVal: float) -> None: ...
    def GetNumCalibLevels(self) -> int: ...
    def SetLevelResponse(self, usLevelNo0Based: int, dResp: float) -> None: ...
    def SetQualifierPctUncertainty(
        self, usQualNo0Based: int, dPctUnc: float
    ) -> None: ...
    def SetLevelConcentration(self, usLevelNo0Based: int, dConc: float) -> None: ...
    def SetQuantRole(
        self,
        iISTD: Agilent.MassSpectrometry.MSDChem.QDB.QuantDatabaseCompoundRoles,
        fTimeReference: bool,
    ) -> None: ...
    def ClearLevelInfo(self, usLevelNo0Based: int) -> None: ...
    def GetQualifierMz20ths(self, usQualNo0Based: int) -> int: ...
    def SetQuantWithGCSig(self, usSelection: int) -> None: ...
    def GetQualifierPctUncertainty(self, usQualNo0Based: int) -> float: ...
    @staticmethod
    def QUANT_SET_CF_TYPE(a: int, val: int) -> None: ...
    def GetLevelConcentration(self, usLevelNo0Based: int) -> float: ...
    def SetQualifierAreaSummed(self, usQualNo0Based: int, flag: int) -> None: ...
    @staticmethod
    def QUANT_GET_WT_TYPE(a: int) -> int: ...
    def MakeNull(self) -> None: ...
    def SetMatrixLowConc(self, usMatrixID: int, dLowConc: float) -> None: ...
    def SetQualifierIntegPFName(
        self, usQualNo0Based: int, pIntegFileName: str
    ) -> None: ...
    def SetMatrixMinDetLimit(self, usMatrixID: int, dRPD: float) -> None: ...
    def GetMatrixMinDetLimit(self, usMatrixID: int) -> float: ...
    def GetUserDefinedString(self, usUserIndex: int) -> str: ...
    def SetMatrixRelPctDev(self, usMatrixID: int, dRPD: float) -> None: ...
    def SetQualifierMz20ths(self, usQualNo0Based: int, usMz20ths: int) -> None: ...
    def IsISTD(self) -> bool: ...
    def GetQualifierRelResp(self, usQualNo0Based: int) -> float: ...
    def GetRetentionTimeBounds(self, leftBound: int, rightBound: int) -> None: ...
    def SetUserDefinedScalar(self, usUserIndex: int, dValue: float) -> None: ...
    @staticmethod
    def NewCompound(
        phCpnd: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_CPNDENTRY,
        quantEnvironment: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_ENVIRONMENT,
    ) -> None: ...
    def MakeNullLevelResponse(self, usLevelNo0Based: int) -> None: ...
    @staticmethod
    def GetRtBounds(
        actual_rt: int,
        rt_d_left: float,
        rt_d_right: float,
        rt_win_modifier: int,
        leftBound: int,
        rightBound: int,
    ) -> None: ...
    def SetLevelAverageCount(
        self, usLevelNo0Based: int, usAverageCount: int
    ) -> None: ...
    def GetUserDefinedScalar(self, usUserIndex: int) -> float: ...
    def ClearCalibLevelInfo(self, usLevelNo0Based: int) -> None: ...
    @staticmethod
    def QUANT_GET_CF_TYPE(a: int) -> int: ...
    def GetQualifierIntegPFName(self, usQualNo0Based: int) -> str: ...
    def GetMatrixLowConc(self, usMatrixID: int) -> float: ...
    def SetMatrixHighConc(self, usMatrixID: int, dHighConc: float) -> None: ...
    def MakeNullRecord(
        self, env: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_ENVIRONMENT
    ) -> None: ...
    @staticmethod
    def DeleteCompound(
        hCpnd: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_CPNDENTRY,
    ) -> None: ...
    def QualifierExists(self, usQualNo0Based: int) -> bool: ...
    def GetQualifierAreaSummed(self, usQualNo0Based: int) -> bool: ...
    def LevelInfoExists(self, usLevelNo0Based: int) -> bool: ...
    @staticmethod
    def QUANT_SET_WT_TYPE(a: int, val: int) -> None: ...
    def GetLevelAverageCount(self, usLevelNo0Based: int) -> int: ...
    def SetQualifierRelResp(self, usQualNo0Based: int, dRelResp: float) -> None: ...
    def GetLevelResponse(self, usLevelNo0Based: int) -> float: ...
    def GetMatrixHighConc(self, usMatrixID: int) -> float: ...
    def SetUserDefinedString(self, usUserIndex: int, pValue: str) -> None: ...
    def GetMatrixRelPctDev(self, usMatrixID: int) -> float: ...
    def ValidateEntry(self, strErrorMessage: str) -> bool: ...

class QUANT_ENVIRONMENT:  # Class
    def __init__(self) -> None: ...

    calStdDirName: str
    calStdFileName: List[str]
    db_timestamp: str
    defUnitsStr: str
    level_id: List[str]
    paramFile: str
    title: str
    unusedLvlConc: List[float]

    UseRTEINT: bool
    corrWin: int
    defCurveFit: int
    defIstdConc: float
    defSampleAmt: float
    internalVersionNum: int
    multiplier: float
    nonRefWin: int
    nonRefWinType: int
    outputType: int
    quantByHeight: int
    refWin: int
    refWinType: int
    rptFileName: str
    rt_radius: int
    runMethod: int
    singleCpndNum: int
    toFile: int
    toPrinter: int
    toScreen: int

    @overload
    def ConvertQuantEnvironment(
        self,
        pOldEnv: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_ENVIRONMENT_PRE_D_00_00,
    ) -> None: ...
    @overload
    def ConvertQuantEnvironment(
        self, pOldEnv: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_ENVIRONMENT_2002
    ) -> None: ...
    def Serialize(self, archive: Any, nVersion: int) -> None: ...

class QUANT_ENVIRONMENT_2002:  # Class
    ...

class QUANT_ENVIRONMENT_PRE_D_00_00:  # Class
    ...

class QUANT_QDB_MEMHANDLE:  # Class
    def __init__(self) -> None: ...

    GetQuantDB: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_QDB_MEMMAP  # readonly

    def StoreQuantDatabase(
        self, pDatabaseContainer: str, pDatabaseComponent: str
    ) -> None: ...
    def LoadQuantDatabase(
        self, pDatabaseContainer: str, pDatabaseComponent: str
    ) -> None: ...

class QUANT_QDB_MEMMAP:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, iInitialSizeInEntries: int) -> None: ...

    QUANT_ANY: int = ...  # static # readonly
    QUANT_AREAPCT_UNCALIB_REP: int = ...  # static # readonly
    QUANT_DETAILED_NOGR_REP: int = ...  # static # readonly
    QUANT_DETAILED_REP: int = ...  # static # readonly
    QUANT_DETAILED_SNGL_REP: int = ...  # static # readonly
    QUANT_ISTD: int = ...  # static # readonly
    QUANT_SELECT: int = ...  # static # readonly
    QUANT_SUMMARY_REP: int = ...  # static # readonly
    QUANT_TIMEREF: int = ...  # static # readonly
    dbRec: System.Collections.Generic.List[
        Agilent.MassSpectrometry.MSDChem.QDB.QUANT_CPNDENTRY
    ]
    env: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_ENVIRONMENT

    def InsertEntry(
        self,
        hCpnd: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_CPNDENTRY,
        newEntryLoc0Based: int,
    ) -> None: ...
    def DeleteCalibLvlRange(self, levelStart: int, levelEnd: int) -> None: ...
    def DeleteEntry(self, deletedEntryLoc: int) -> None: ...
    def GetRelatedIstdCpndNum(
        self, cpndSeqNumber: int, pusRelatedIstdCpndNum: int
    ) -> bool: ...
    def IsIstdAnalyte(
        self, hCpnd: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_CPNDENTRY
    ) -> bool: ...
    def GetNextCpnd(self, indexSize: int, cpndType: int, nextCpndNum: int) -> None: ...
    def ClearCpnds(
        self, fClearLevelsOnly: bool, fBatchMode: bool, msg: str
    ) -> bool: ...
    def GetSizeInEntries(self) -> int: ...
    def UpdateEntry(
        self, hCpnd: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_CPNDENTRY, entryNo: int
    ) -> None: ...
    def GetCompoundNumber(
        self,
        usCpndNum0Based: int,
        phCpnd: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_CPNDENTRY,
    ) -> None: ...
    def SetDbTimeStamp(self) -> None: ...
    def GetRelatedIstd(
        self,
        pCpnd: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_CPNDENTRY,
        pRelatedIstdCpnd: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_CPNDENTRY,
    ) -> None: ...

class QUANT_QUALIFIER_ADDITIONAL_INFO:  # Class
    @overload
    def __init__(
        self, dPercentUncertainty: float, bAreaSum: bool, strParamFile: str
    ) -> None: ...
    @overload
    def __init__(
        self,
        source: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_QUALIFIER_ADDITIONAL_INFO,
    ) -> None: ...
    @overload
    def __init__(self) -> None: ...

    IsSummed: bool
    ParameterFileName: str
    PercentUncertainty: int

class QUANT_QUALIFIER_ION:  # Class
    @overload
    def __init__(self, dMZ: float, dRelResponse: float) -> None: ...
    @overload
    def __init__(
        self, source: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_QUALIFIER_ION
    ) -> None: ...
    @overload
    def __init__(self) -> None: ...

    MZ: int
    Rel_Response: int

class QUANT_RESULTS:  # Class
    def __init__(self) -> None: ...

    alternateHitIndex: int
    coeff: List[float]
    istdResponse: float
    modified: int
    nTotalHits: int
    primaryHit: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_SINGLE_HIT
    primaryHitNumber: int
    qual_ratio_hi: List[float]
    qual_ratio_lo: List[float]
    rf: List[float]

    AdjustedExpectedRetentionTime: int
    CompoundRetentionTimeHigh: int
    CompoundRetentionTimeLow: int
    ConstantCalibrationCurveCoefficient: float  # readonly
    IStdCompoundLocation: int
    LinearCalibrationCurveCoefficient: float  # readonly
    QuadraticCalibrationCurveCoefficient: float  # readonly
    Rho: float

    def GetQualifierRatioHigh(self, i32WhichQualifier: int) -> float: ...
    def GetQualifierRatioLow(self, i32WhichQualifier: int) -> float: ...

class QUANT_RSLTFILE_HDR:  # Class
    def __init__(self) -> None: ...

    env: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_ENVIRONMENT

    NumberOfInternalStandards: int  # readonly
    NumberOfResults: int  # readonly
    NumberOfTimeReferenceCompounds: int  # readonly

class QUANT_RSLTFILE_MEMMAP:  # Class
    def __init__(self, fileName: str) -> None: ...

    alternateHits: System.Collections.Generic.List[
        Agilent.MassSpectrometry.MSDChem.QDB.QUANT_SINGLE_HIT
    ]
    header: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_RSLTFILE_HDR
    mainResults: System.Collections.Generic.List[
        Agilent.MassSpectrometry.MSDChem.QDB.QUANT_RSLT_FILE_REC
    ]

    def Save(self) -> None: ...
    def Load(self) -> None: ...
    def InitQuantResult(
        self,
        quantDatabase: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_QDB_MEMMAP,
        numEntries: int,
        nTimeRefs: int,
        nIstds: int,
        rsltFileName: str,
        bSecondPassHack: bool,
    ) -> None: ...

class QUANT_RSLT_FILE_REC:  # Class
    def __init__(self) -> None: ...

    dbEntry: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_CPNDENTRY
    rslt: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_RESULTS

class QUANT_SINGLE_HIT(
    System.IComparable[Agilent.MassSpectrometry.MSDChem.QDB.QUANT_SINGLE_HIT]
):  # Class
    def __init__(self) -> None: ...

    amtRatio: float
    areaCorrResp: float
    determined_amt: float
    ending_baseline: float
    ending_time: int
    groupIndex: int
    group_rt: int
    identified: int
    qValueComputed: int
    qValueKey: int
    qdel: int
    qualifier_end_bl: List[float]
    qualifier_end_time: List[int]
    qualifier_resp: List[float]
    qualifier_rt: List[int]
    qualifier_st_bl: List[float]
    qualifier_st_time: List[int]
    respRatio: float
    response: float
    rtDiffKey: int
    starting_baseline: float
    starting_time: int
    tgt_rt: int

    def CompareTo(
        self, other: Agilent.MassSpectrometry.MSDChem.QDB.QUANT_SINGLE_HIT
    ) -> int: ...

class QUANT_TARGET_ADDITIONAL_INFO:  # Class
    paramFile: str

class QUANT_TARGET_SIGNAL:  # Class
    actual_rt: int
    mz: int

class QuantDatabaseCompoundRoles(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    QUANT_ROLE_ISTD: Agilent.MassSpectrometry.MSDChem.QDB.QuantDatabaseCompoundRoles = (
        ...
    )  # static # readonly
    QUANT_ROLE_SEMIQUANT: (
        Agilent.MassSpectrometry.MSDChem.QDB.QuantDatabaseCompoundRoles
    ) = ...  # static # readonly
    QUANT_ROLE_TARGET_COMPOUND: (
        Agilent.MassSpectrometry.MSDChem.QDB.QuantDatabaseCompoundRoles
    ) = ...  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ECMHelper.ViewModel

class FileListFilter:  # Class
    def __init__(self, text: str, extensions: str) -> None: ...

    Extensions: List[str]  # readonly
    Text: str  # readonly

    def Match(self, name: str) -> bool: ...
    def ToString(self) -> str: ...

class FileListViewModel(System.ComponentModel.INotifyPropertyChanged):  # Class
    def __init__(self) -> None: ...

    CommandCheckout: System.Windows.Input.ICommand  # readonly
    CommandUndoCheckout: System.Windows.Input.ICommand  # readonly
    Filters: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ECMHelper.ViewModel.FileListFilter
    )
    Items: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ECMHelper.ViewModel.ListItemViewModel
    ]  # readonly
    OpenCommandText: str  # readonly
    OpenCommandVisibility: System.Windows.Visibility  # readonly
    OpenRevisionVisibility: System.Windows.Visibility  # readonly
    OpenSeparatorVisibility: System.Windows.Visibility  # readonly
    Window: System.Windows.Window

    def UpdateItems(self, path: str) -> None: ...
    def Sort(self, name: str) -> None: ...

    PropertyChanged: System.ComponentModel.PropertyChangedEventHandler  # Event

class FolderTreeViewModel:  # Class
    def __init__(self) -> None: ...

    Folders: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ECMHelper.ViewModel.TreeItemViewModel
    ]  # readonly

class ListItemViewModel(System.ComponentModel.INotifyPropertyChanged):  # Class
    def __init__(self) -> None: ...

    CheckedOut: Optional[bool]
    CheckedOutByCurrentUser: bool
    CheckoutImage: System.Windows.Media.ImageSource
    CheckoutReason: str
    CheckoutTime: Optional[System.DateTime]
    CheckoutUser: str
    CreateDate: str
    Image: System.Windows.Media.ImageSource
    IsFolder: bool
    ModifiedDate: str
    Name: str
    RevisionNumber: Optional[int]
    UploadDate: Optional[System.DateTime]
    UploadReason: str
    UploadUser: str
    _CheckoutTime: str  # readonly
    _UploadDate: str  # readonly

    def Update(self) -> Any: ...

    PropertyChanged: System.ComponentModel.PropertyChangedEventHandler  # Event

class TreeItemViewModel(System.ComponentModel.INotifyPropertyChanged):  # Class
    def __init__(self) -> None: ...

    Children: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ECMHelper.ViewModel.TreeItemViewModel
    ]  # readonly
    FolderLevel: int
    Image: System.Windows.Media.ImageSource
    IsExpanded: bool
    IsLastLevelFolder: bool
    IsSelected: bool
    Name: str
    Parent: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ECMHelper.ViewModel.TreeItemViewModel
    )  # readonly
    PathName: str

    PropertyChanged: System.ComponentModel.PropertyChangedEventHandler  # Event



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ECMHelper.Properties

class Resources:  # Class
    BatchFileBin: System.Drawing.Bitmap  # static # readonly
    ButtonLabel_Close: str  # static # readonly
    ButtonLabel_Verify: str  # static # readonly
    ButtonOk_New: str  # static # readonly
    ButtonOk_Open: str  # static # readonly
    ButtonOk_Save: str  # static # readonly
    Checkout: System.Drawing.Bitmap  # static # readonly
    CheckoutByme: System.Drawing.Bitmap  # static # readonly
    Culture: System.Globalization.CultureInfo  # static
    Err_CannotLogin: str  # static # readonly
    Err_CannotValidateUser: str  # static # readonly
    Exp_BatchFileNotFoundInZip: str  # static # readonly
    Exp_CannotFindPDFPrintConfiguration: str  # static # readonly
    Exp_CannotReadBatchInformation: str  # static # readonly
    Exp_ExtractElement: str  # static # readonly
    Exp_FolderNotExist: str  # static # readonly
    File: System.Drawing.Bitmap  # static # readonly
    Folder_6222: System.Drawing.Icon  # static # readonly
    Method: System.Drawing.Bitmap  # static # readonly
    Msg_FailedToCheckout: str  # static # readonly
    Msg_FailedToUndoCheckout: str  # static # readonly
    Msg_FileAlreadyCheckedout: str  # static # readonly
    Msg_FileAlreadyExists: str  # static # readonly
    Msg_FileAlreadyExistsReplace: str  # static # readonly
    Msg_FileNotFoundCheck: str  # static # readonly
    Msg_LoggingIn: str  # static # readonly
    Msg_NoPrivilegeToCheckout: str  # static # readonly
    Msg_NoPrivilegeToReadFolders: str  # static # readonly
    Msg_NoPrivilegeToUndoCheckout: str  # static # readonly
    ResourceManager: System.Resources.ResourceManager  # static # readonly
    Sample: System.Drawing.Icon  # static # readonly
    Title_NewFile: str  # static # readonly
    Title_OpenFile: str  # static # readonly
    Title_SaveFileAs: str  # static # readonly
    Title_ValidateUser: str  # static # readonly
    UnknownsFile: System.Drawing.Bitmap  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Commands, ReportFixedGraphicsDataSet, Tools

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportFixedGraphics

class AppException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...

class CommandLine:  # Class
    def __init__(self) -> None: ...

    Culture: str
    File: str

    def Form_Shown(self, sender: Any, e: System.EventArgs) -> None: ...

class CompoundGridView(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.DataGridView,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...
    def Initialize(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportFixedGraphics.Context,
    ) -> None: ...
    def Copy(self) -> None: ...
    def CanCopy(self) -> bool: ...
    def CanPaste(self) -> bool: ...
    def Delete(self, copyToClipboard: bool) -> None: ...
    def Paste(self) -> None: ...
    def CanDelete(self) -> bool: ...

class Context(
    Agilent.MassSpectrometry.CommandModel.Model.ICommandHistory,
    Agilent.MassSpectrometry.CommandModel.CommandHistory,
    System.IDisposable,
):  # Class
    def __init__(self) -> None: ...

    DataSet: ReportFixedGraphicsDataSet  # readonly
    File: str  # readonly
    IsDirty: bool  # readonly
    NewCompound: ReportFixedGraphicsDataSet.CompoundRow  # readonly

    def Save(self) -> None: ...
    def Open(self, file: str, readOnly: bool) -> None: ...
    def StartNewCompound(self) -> None: ...
    def NewFile(self) -> None: ...
    def SetNewCompoundColumn(self, name: str, value_: Any) -> None: ...
    def SetCompoundColumn(self, compoundName: str, name: str, value_: Any) -> None: ...
    def NewSample(self, sampleName: str) -> None: ...
    def CancelNewCompound(self) -> None: ...
    def SaveAs(self, path: str) -> None: ...
    def SetSampleColumn(self, sampleName: str, name: str, value_: Any) -> None: ...
    def RemoveSample(self, sampleName: str) -> None: ...
    def CommitNewCompound(self) -> None: ...
    def RemoveCompound(self, compoundName: str) -> None: ...

    NewCompoundCancel: System.EventHandler  # Event
    NewCompoundColumnChanged: System.Data.DataColumnChangeEventHandler  # Event
    NewCompoundCommit: System.EventHandler  # Event
    NewCompoundStart: System.EventHandler  # Event

class MainForm(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    Context: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportFixedGraphics.Context
    )  # readonly
    FilePath: str  # readonly

    def OpenFile(self, file: str, readOnly: bool) -> bool: ...
    def Copy(self) -> None: ...
    def CanCopy(self) -> bool: ...
    def CanPaste(self) -> bool: ...
    def CommitEdit(self, commitNewRow: bool) -> bool: ...
    def Delete(self, copyToClipboard: bool) -> None: ...
    def Paste(self) -> None: ...
    def CanDelete(self) -> bool: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.SetupDesktopIconsWPF

class App(
    System.Windows.Application,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...

    CANCELED: int = ...  # static # readonly
    ERROR: int = ...  # static # readonly
    SUCCESS: int = ...  # static # readonly

    @staticmethod
    def GetLogfilePath(logfileFolderName: str, filenamePrefix: str) -> str: ...
    def InitializeComponent(self) -> None: ...
    @staticmethod
    def SetupLogfileTraceListener() -> None: ...
    @staticmethod
    def Main() -> None: ...

class CommandLine:  # Class
    def __init__(self) -> None: ...

    Append: bool  # readonly
    Culture: str  # readonly
    Icons: List[str]  # readonly
    Install: bool  # readonly
    Silent: bool  # readonly
    Uninstall: bool  # readonly

    def Parse(self, args: List[str]) -> None: ...

class FlavorIconsViewModel:  # Class
    def __init__(self) -> None: ...
    def __getitem__(self, name: str) -> bool: ...
    def __setitem__(self, name: str, value_: bool) -> None: ...
    Vanilla: bool

    def Clear(self) -> None: ...
    def CreateShortcuts(
        self,
    ) -> List[Agilent.MassHunter.Quantitative.SetupDesktopIconsWPF.Shortcut]: ...

class IconItem:  # Class
    def __init__(self) -> None: ...

    DQ: bool
    EQ: bool
    Instrument: str
    STD: bool

    def Clear(self) -> None: ...
    def CreateShortcuts(
        self, inst: str, isGC: bool, wpf: bool
    ) -> List[Agilent.MassHunter.Quantitative.SetupDesktopIconsWPF.Shortcut]: ...

class MainViewModel:  # Class
    def __init__(self) -> None: ...

    ClassicIcons: (
        Agilent.MassHunter.Quantitative.SetupDesktopIconsWPF.QuantIconsViewModel
    )  # readonly
    FlavorIcons: (
        Agilent.MassHunter.Quantitative.SetupDesktopIconsWPF.FlavorIconsViewModel
    )  # readonly
    OpenLabIcons: (
        Agilent.MassHunter.Quantitative.SetupDesktopIconsWPF.OpenLabIconsViewModel
    )  # readonly

    def Initialize(self, icons: List[str], append: bool) -> None: ...
    def SetupShortcuts(self) -> None: ...

class MainWindow(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.IWindowService,
    Infragistics.Windows.Ribbon.IRibbonWindow,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Animation.IAnimatable,
    System.ComponentModel.ISupportInitialize,
    Infragistics.Windows.Ribbon.XamRibbonWindow,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.Windows.Markup.IAddChild,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class OpenLabIconsViewModel(
    Agilent.MassHunter.Quantitative.SetupDesktopIconsWPF.QuantIconsViewModel
):  # Class
    def __init__(self) -> None: ...

    StartupRootFolderProperty: System.Windows.DependencyProperty  # static

    QuantMyWayIcon: bool
    StartupRootFolder: str

    def Clear(self) -> None: ...
    def CreateShortcuts(
        self, wpf: bool
    ) -> List[Agilent.MassHunter.Quantitative.SetupDesktopIconsWPF.Shortcut]: ...

class QuantIconsViewModel(System.Windows.DependencyObject):  # Class
    def __init__(self) -> None: ...

    GC: Agilent.MassHunter.Quantitative.SetupDesktopIconsWPF.IconItem  # readonly
    MS: Agilent.MassHunter.Quantitative.SetupDesktopIconsWPF.IconItem  # readonly
    QQQ: Agilent.MassHunter.Quantitative.SetupDesktopIconsWPF.IconItem  # readonly
    QTOF: Agilent.MassHunter.Quantitative.SetupDesktopIconsWPF.IconItem  # readonly
    TOF: Agilent.MassHunter.Quantitative.SetupDesktopIconsWPF.IconItem  # readonly
    UA: bool

    def Clear(self) -> None: ...
    def CreateShortcuts(
        self, wpf: bool
    ) -> List[Agilent.MassHunter.Quantitative.SetupDesktopIconsWPF.Shortcut]: ...

class QuantIonsControl(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IHaveResources,
    System.Windows.IInputElement,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Controls.Grid,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class Shortcut:  # Class
    def __init__(self) -> None: ...

    Application: str
    Desktop: str
    Flavor: str
    Instrument: str
    StartMenu: str
    UA: bool
    WPF: bool

class Shortcuts:  # Class
    def __init__(self) -> None: ...

    CreatedShortcuts: List[
        Agilent.MassHunter.Quantitative.SetupDesktopIconsWPF.Shortcut
    ]



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportTasks.Options

class ExcelReportControl:  # Class
    def __init__(self) -> None: ...

    Command: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportTasks.Options.ExcelReportControlCommand
    )
    Options: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportTasks.Options.ExcelReportControlOptions
    )

class ExcelReportControlCommand:  # Class
    def __init__(self) -> None: ...

    DestinationFullName: str
    ExcelBinaryPathName: str
    ExcelTemplatePathName: str
    GraphicsPathName: str
    PrinterName: str
    PublishFormat: str
    ReportFileDestination: str
    ReportPrinterDestination: str
    ResultsFullName: str
    UserName: str

class ExcelReportControlOptions:  # Class
    def __init__(self) -> None: ...

    IncludeFooter: bool
    IncludeHeader: bool
    IncludeTitle: bool
    Orientation: str
    TableColumns: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportTasks.Options.ExcelReportControlOptionsTableColumns
    )
    TableSorting: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportTasks.Options.ExcelReportControlOptionsTableSorting
    )
    XPages: str
    YPages: str

class ExcelReportControlOptionsTableColumns:  # Class
    def __init__(self) -> None: ...

    Column: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportTasks.Options.ExcelReportControlOptionsTableColumnsColumn
    ]
    Count: str
    TableName: str

class ExcelReportControlOptionsTableColumnsColumn:  # Class
    def __init__(self) -> None: ...

    Format: str
    Index: str
    XPath: str

class ExcelReportControlOptionsTableSorting:  # Class
    def __init__(self) -> None: ...

    Count: str
    Sort: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportTasks.Options.ExcelReportControlOptionsTableSortingSort
    ]
    TableName: str

class ExcelReportControlOptionsTableSortingSort:  # Class
    def __init__(self) -> None: ...

    Column: str
    Index: str
    Order: str



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.Acquisition

class DevicesConstants:  # Class
    Delay: str = ...  # static # readonly
    DeviceID: str = ...  # static # readonly
    DeviceName: str = ...  # static # readonly
    DeviceType: str = ...  # static # readonly
    DisplayName: str = ...  # static # readonly
    DriverVersion: str = ...  # static # readonly
    FirmwareVersion: str = ...  # static # readonly
    ModelNumber: str = ...  # static # readonly
    OrdinalNumber: str = ...  # static # readonly
    SerialNumber: str = ...  # static # readonly
    StoredDataType: str = ...  # static # readonly
    VendorID: str = ...  # static # readonly

class DevicesManager:  # Class
    def __init__(self) -> None: ...
    def Write(self) -> None: ...
    def GetDeviceID(self, Name: str, OrdinalNumber: int) -> int: ...
    def Init(self, acqDataPath: str) -> None: ...
    def Close(self) -> None: ...
    @overload
    def AddDevice(
        self,
        Name: str,
        ModelNumber: str,
        OrdinalNumber: int,
        SerialNumber: str,
        Type: int,
        StoredDataType: int,
        Delay: float,
        VendorId: int,
        DriverVersion: str,
        FirmwareVersion: str,
    ) -> None: ...
    @overload
    def AddDevice(
        self,
        Name: str,
        ModelNumber: str,
        OrdinalNumber: int,
        SerialNumber: str,
        Type: int,
        StoredDataType: int,
        Delay: float,
        VendorId: int,
    ) -> None: ...

class ILCDataWriter(object):  # Interface
    def SetFirmwareVersion(self, FirmwareVersion: str) -> None: ...
    def Open(self, DataFileName: str) -> None: ...
    def AddSignal(
        self,
        Name: str,
        Description: str,
        XStart: float,
        XDelta: float,
        YAxisLabel: str,
        YArray: List[float],
    ) -> None: ...
    def EndRCSpectraDevice(self) -> None: ...
    def EndDevice(self) -> None: ...
    def SetDriverVersion(self, DriverVersion: str) -> None: ...
    def StartRCDevice(
        self, DeviceName: str, ModelNumber: str, OrdinalNumber: int, SerialNumber: str
    ) -> None: ...
    def Close(self) -> None: ...
    def EndRCDevice(self) -> None: ...
    def AddSpectrum(
        self, ScanTime: float, SamplingPeriod: float, XStart: float, YArray: List[float]
    ) -> None: ...
    def AddChromatogram(
        self,
        Name: str,
        Description: str,
        XStart: float,
        XDelta: float,
        YAxisLabel: str,
        YArray: List[float],
    ) -> None: ...
    def SetDeviceVendor(self, Vendor: int) -> None: ...
    def StartDevice(
        self,
        DeviceName: str,
        ModelNumber: str,
        OrdinalNumber: int,
        SerialNumber: str,
        DeviceTypeID: int,
    ) -> None: ...

class LCDataWriter(Agilent.MassSpectrometry.Acquisition.ILCDataWriter):  # Class
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .PlotControl import GridPlotContent, GridPlotPane, IPlotSeries, PlotMode, Range
from .ToolbarWPF.ToolManager import IToolManager, ToolManagerBase
from .UIModel import ICalibrationAtAGlanceWindow

# Stubs for namespace: Agilent.MassHunter.Quantitative.CalibrationCurveAtAGlance

class GridPlotContent(
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.IInputElement,
    System.Windows.Markup.IQueryAmbient,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Controls.Primitives.IScrollInfo,
    System.Windows.Markup.IHaveResources,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.IFrameworkInputElement,
):  # Class
    def __init__(self) -> None: ...
    def Initialize(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
    ) -> None: ...
    def GetAutoScaleRange(self, pane: GridPlotPane, vertical: bool) -> Range: ...
    def Uninitialize(self) -> None: ...
    def GetSelectedTargetCompounds(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TargetCompoundRowId
    ]: ...
    def SetDimension(self, rows: int, columns: int) -> None: ...

class MainWindow(
    System.Windows.Markup.IAddChild,
    Infragistics.Windows.Ribbon.XamRibbonWindow,
    System.Windows.Markup.IHaveResources,
    System.Windows.IInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.IFrameworkInputElement,
    Infragistics.Windows.Ribbon.IRibbonWindow,
    System.Windows.Media.Composition.DUCE.IResource,
    ICalibrationAtAGlanceWindow,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.IWindowService,
    System.Windows.Forms.IWin32Window,
):  # Class
    def __init__(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
    ) -> None: ...

    ContainsFocus: bool  # readonly
    Handle: System.IntPtr  # readonly
    Location: System.Drawing.Point
    NumColumnsPerPage: int  # readonly
    NumRowsPerPage: int  # readonly
    Visible: bool  # readonly
    WindowState: System.Windows.Forms.FormWindowState

    def SetDimension(self, rows: int, columns: int) -> None: ...
    @staticmethod
    def GetInstance(
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
    ) -> Agilent.MassHunter.Quantitative.CalibrationCurveAtAGlance.MainWindow: ...
    def InitializeComponent(self) -> None: ...
    def GetSelectedTargetCompounds(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TargetCompoundRowId
    ]: ...

class PlotSeries(IPlotSeries):  # Class
    def __init__(
        self,
        compound: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow,
        ccf: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CalibrationCurveFit,
    ) -> None: ...

    CalibrationCurveFit: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CalibrationCurveFit
    )  # readonly
    CompoundName: str  # readonly
    CompoundRow: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundRow
    )  # readonly
    Count: int  # readonly
    Pen: System.Windows.Media.Pen  # readonly
    PlotMode: PlotMode  # readonly
    Visible: bool  # readonly

    def SetPane(self, pane: GridPlotPane) -> None: ...
    def GetPoint(self, index: int, x: float, y: float) -> None: ...
    def GetCompoundID(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.TargetCompoundRowId: ...

class ToolHandlerView(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolBeforeDropdownHandler,
):  # Class
    def __init__(self) -> None: ...
    def Execute(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        objUiState: Any,
    ) -> None: ...
    def SetState(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        state: Any,
    ) -> None: ...

class ToolManager(
    ToolManagerBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolManager,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbarsManager,
    IToolManager,
):  # Class
    def __init__(
        self, ribbon: Infragistics.Windows.Ribbon.XamRibbon, uiState: Any
    ) -> None: ...
    def RegisterScriptCategoryHandler(
        self, category: str, module: str, setState: str, execute: str
    ) -> None: ...
    def RegisterScriptToolHandler(
        self, id: str, module: str, setState: str, execute: str
    ) -> None: ...
    @overload
    def GetToolCaption(
        self, id: str, culture: System.Globalization.CultureInfo
    ) -> str: ...
    @overload
    def GetToolCaption(self, id: str) -> str: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import NotifyPropertyChangedBase

# Stubs for namespace: Agilent.MassHunter.ReportBuilder.DataSource.Quant.CustomUI.InsertTable

class IInsertTableView(object):  # Interface
    CanOK: bool  # readonly

    def OnOK(self) -> None: ...

    CanOKChanged: System.EventHandler  # Event

class InsertTableWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(
        self,
        application: Agilent.MassHunter.ReportBuilder.Application.IApplication,
        designer: Agilent.MassHunter.ReportBuilder.DataSource.IDataSourceDesigner,
    ) -> None: ...

    Application: Agilent.MassHunter.ReportBuilder.Application.IApplication  # readonly
    DataSourceDesigner: (
        Agilent.MassHunter.ReportBuilder.DataSource.IDataSourceDesigner
    )  # readonly
    Handled: bool  # readonly

    def InitializeComponent(self) -> None: ...

class InsertTableWindowModel(
    System.ComponentModel.INotifyPropertyChanged, NotifyPropertyChangedBase
):  # Class
    def __init__(
        self,
        window: Agilent.MassHunter.ReportBuilder.DataSource.Quant.CustomUI.InsertTable.InsertTableWindow,
    ) -> None: ...

    Application: Agilent.MassHunter.ReportBuilder.Application.IApplication  # readonly
    CanInsert: bool  # readonly
    CanOK: bool  # readonly
    CommandCancel: System.Windows.Input.ICommand  # readonly
    CommandOk: System.Windows.Input.ICommand  # readonly
    Container: (
        Agilent.MassHunter.ReportBuilder.DataModel.ISelectableContainer
    )  # readonly
    CurrentChildViewModel: (
        Agilent.MassHunter.ReportBuilder.DataSource.Quant.CustomUI.InsertTable.IInsertTableView
    )
    Handled: bool
    InsertIndex: int  # readonly
    IsCompounds: bool

    def OnOK(self) -> None: ...
    def CloseWindow(self, handled: bool) -> None: ...

class PageCompounds(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class PageCompoundsViewModel(
    System.ComponentModel.INotifyPropertyChanged,
    Agilent.MassHunter.ReportBuilder.DataSource.Quant.CustomUI.InsertTable.IInsertTableView,
    NotifyPropertyChangedBase,
):  # Class
    def __init__(
        self,
        model: Agilent.MassHunter.ReportBuilder.DataSource.Quant.CustomUI.InsertTable.InsertTableWindowModel,
    ) -> None: ...

    BindingName: str
    CanOK: bool  # readonly
    IncludeISTDPeaks: bool
    IncludeISTDs: bool
    IncludePeaks: bool

    def OnOK(self) -> None: ...

    CanOKChanged: System.EventHandler  # Event



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .OS import FolderViewMode

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls

class AddonWindowLocation(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Bottom: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.AddonWindowLocation
    ) = ...  # static # readonly
    Right: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.AddonWindowLocation
    ) = ...  # static # readonly

class ControlsID(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    ButtonCancel: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.ControlsID
    ) = ...  # static # readonly
    ButtonHelp: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.ControlsID
    ) = ...  # static # readonly
    ButtonOpen: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.ControlsID
    ) = ...  # static # readonly
    CheckBoxReadOnly: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.ControlsID
    ) = ...  # static # readonly
    ComboFileName: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.ControlsID
    ) = ...  # static # readonly
    ComboFileType: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.ControlsID
    ) = ...  # static # readonly
    ComboFolder: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.ControlsID
    ) = ...  # static # readonly
    DefaultView: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.ControlsID
    ) = ...  # static # readonly
    GroupFolder: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.ControlsID
    ) = ...  # static # readonly
    LabelFileName: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.ControlsID
    ) = ...  # static # readonly
    LabelFileType: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.ControlsID
    ) = ...  # static # readonly
    LabelLookIn: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.ControlsID
    ) = ...  # static # readonly
    LeftToolBar: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.ControlsID
    ) = ...  # static # readonly

class OpenFileDialogEx(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...

    DefaultViewMode: FolderViewMode
    OpenDialog: System.Windows.Forms.OpenFileDialog  # readonly
    StartLocation: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.AddonWindowLocation
    )

    def OnFileNameChanged(self, fileName: str) -> None: ...
    def OnClosingDialog(self) -> None: ...
    def OnFolderNameChanged(self, folderName: str) -> None: ...
    @overload
    def ShowDialog(self) -> System.Windows.Forms.DialogResult: ...
    @overload
    def ShowDialog(
        self, owner: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...

    ClosingDialog: System.EventHandler  # Event
    FileNameChanged: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.OpenFileDialogEx.PathChangedHandler
    )  # Event
    FolderNameChanged: (
        Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.OpenFileDialogEx.PathChangedHandler
    )  # Event

    # Nested Types

    class PathChangedHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.OpenFileDialogEx,
            filePath: str,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            sender: Agilent.MassSpectrometry.DataAnalysis.MetaboliteID.Controls.OpenFileDialogEx,
            filePath: str,
        ) -> None: ...
